@@ -76,10 +76,11 @@ class Snake():
         newY = self._y - round(amount * math.cos(math.radians(self._rotation)), 1)
         self._moveTo(newX, newY)
     
-    def display(self, canvWidth = 400, canvHeight = 200):
+    def display(self, canvWidth = 400, canvHeight = 200, draw = True):
         # for some reason it is not doing the last 2 actions... sooooo
         self.goforward(1)
         self.turnright(1)
+        # this is so that each turtle gets their own canvas
         self._randHash = random.getrandbits(128)
         #self._randHash = "asForTurtle";
         ## Canvas creation
@@ -98,5 +99,6 @@ class Snake():
         display(HTML('<script type="text/javascript">var actionData = %s;</script>'% (arrayString)))
         
         ## Drawing the turtle/executing on the injected data
-        display(HTML('<script type="text/paperscript" canvas="canv%s">%s</script>'% (self._randHash, ReadFile('AtahansTurtle.js'))))
+        if(draw):
+            display(HTML('<script type="text/paperscript" canvas="canv%s">%s</script>'% (self._randHash, ReadFile('AtahansTurtle.js'))))
   
\ No newline at end of file
